
![](https://www.jaimedcsilva.com/static/img/python.png)
### Installation 

```sh
pip install jaime38130
```






### Importing:
`from jaime38130 import green`

### Examples with green color:

`green("I needed color")`

![](https://www.jaimedcsilva.com/static/img/jaime38130/standard.png)



`
green("I needed color", "header")
`

![](https://www.jaimedcsilva.com/static/img/jaime38130/header.png)



`
green("I needed color", "*")
`

![](https://www.jaimedcsilva.com/static/img/jaime38130/bottom.png)

`
green("I needed color", "**")
`

![](https://www.jaimedcsilva.com/static/img/jaime38130/top_bottom.png)
 
### Available colors:
green
white
black
cyan
magenta
red
blue
yellow



